using Assets.Scripts;

namespace ChillConnect
{
    public static class ModuleManagerRegister
    {
        public static void AutoRegisterModel()
        {
            ModuleManager moduleManager = ModuleManager.Instance;
            // moduleManager.AddModel(ModelConst.LoginModel, new LoginModels());
            moduleManager.AddModel(ModelConst.RewardAniModel, new RewardAniModel());
            moduleManager.AddModel(ModelConst.GameLoginModel, new GameLoginModel());
            moduleManager.AddModel(ModelConst.JoastModel, new JoastModel());
            moduleManager.AddModel(ModelConst.LoadingModel, new LoadingModel());
            moduleManager.AddModel(ModelConst.MenuModel, new MenuModel());
            moduleManager.AddModel(ModelConst.NetLoadingModel, new NetLoadingModel());
            moduleManager.AddModel(ModelConst.OpenBgModel, new OpenBgModel());
            moduleManager.AddModel(ModelConst.PrivacyModel, new PrivacyModel());
            moduleManager.AddModel(ModelConst.RewardModel, new RewardModel());
            moduleManager.AddModel(ModelConst.RainPlayModel, new RainPlayModel());
            moduleManager.AddModel(ModelConst.ChoosePropModel, new ChoosePropModel());
            moduleManager.AddModel(ModelConst.BuyPropModel, new BuyPropModel());
            moduleManager.AddModel(ModelConst.GameResultModel, new GameResultModel());
            moduleManager.AddModel(ModelConst.AddViewModel, new AddViewModel());
            moduleManager.AddModel(ModelConst.OpenGameModel, new OpenGameModel());
            moduleManager.AddModel(ModelConst.RewardboxModel, new RewardboxModel());
            moduleManager.AddModel(ModelConst.PayloadingModel, new PayloadingModel());
            moduleManager.AddModel(ModelConst.HallModel, new HallModel());
            moduleManager.AddModel(ModelConst.FXWndModel, new FXWndModel());
            moduleManager.AddModel(ModelConst.WheelViewModel, new WheelViewModel());
            moduleManager.AddModel(ModelConst.BuygoldModel, new BuygoldModel());
            moduleManager.AddModel(ModelConst.GameMenuModel, new GameMenuModel());
            moduleManager.AddModel(ModelConst.EggViewModel, new EggViewModel());
            moduleManager.AddModel(ModelConst.PersonViewModel, new PersonViewModel());
            moduleManager.AddModel(ModelConst.TipsViewModel, new TipsViewModel());
            moduleManager.AddModel(ModelConst.LevelRewardModel, new LevelRewardModel());
            moduleManager.AddModel(ModelConst.SignInViewModel, new SignInViewModel());
            moduleManager.AddModel(ModelConst.MakeupConfirmModel, new MakeupConfirmModel());
            moduleManager.AddModel(ModelConst.SaveingPotModel, new SaveingPotModel());
            moduleManager.AddModel(ModelConst.ResurgenceModel, new ResurgenceModel());
            moduleManager.AddModel(ModelConst.FirstRewardModel, new FirstRewardModel());
            moduleManager.AddModel(ModelConst.ThreeDaysGiftModel, new ThreeDaysGiftModel());
            moduleManager.AddModel(ModelConst.PassViewModel, new PassViewModel());
            moduleManager.AddModel(ModelConst.PassunlockModel, new PassunlockModel());
            moduleManager.AddModel(ModelConst.BroadcastModel, new BroadcastModel());
            moduleManager.AddModel(ModelConst.RecordViewModel, new RecordViewModel());
            moduleManager.AddModel(ModelConst.RewardMulNewModel, new RewardMulNewModel());
            moduleManager.AddModel(ModelConst.AdcomingModel, new AdcomingModel());
            moduleManager.AddModel(ModelConst.FAQModel, new FAQModel());
            moduleManager.AddModel(ModelConst.AddViewoffModel, new AddViewoffModel());
            moduleManager.AddModel(ModelConst.RankModel, new RankModel());
            moduleManager.AddModel(ModelConst.RankRewardModel, new RankRewardModel());
            moduleManager.AddModel(ModelConst.RankRuleModel, new RankRuleModel());
            moduleManager.AddModel(ModelConst.PackrewardModel, new PackrewardModel());
            moduleManager.AddModel(ModelConst.GoldRewardModel, new GoldRewardModel());
            moduleManager.AddModel(ModelConst.AddviewnewModel, new AddviewnewModel());
            moduleManager.AddModel(ModelConst.NewTaskModel, new NewTaskModel());
            moduleManager.AddModel(ModelConst.GetTaskRewardModel, new GetTaskRewardModel());
        }
        public static void AutoRegisterUICtrl()
        {
            ModuleManager moduleManager = ModuleManager.Instance;
            moduleManager.AddUICtrl(UICtrlConst.RewardAniUICtrl, new RewardAniUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.GameLoginUICtrl, new GameLoginUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.JoastUICtrl, new JoastUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.LoadingUICtrl, new LoadingUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.MenuUICtrl, new MenuUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.NetLoadingUICtrl, new NetLoadingUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.OpenBgUICtrl, new OpenBgUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.PrivacyUICtrl, new PrivacyUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RewardUICtrl, new RewardUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RainPlayUICtrl, new RainPlayUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.ChoosePropUICtrl, new ChoosePropUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.BuyPropUICtrl, new BuyPropUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.GameResultUICtrl, new GameResultUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.AddViewUICtrl, new AddViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.OpenGameUICtrl, new OpenGameUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RewardboxUICtrl, new RewardboxUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.PayloadingUICtrl, new PayloadingUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.HallUICtrl, new HallUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.FXWndUICtrl, new FXWndUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.WheelViewUICtrl, new WheelViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.BuygoldUICtrl, new BuygoldUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.GameMenuUICtrl, new GameMenuUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.EggViewUICtrl, new EggViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.PersonViewUICtrl, new PersonViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.TipsViewUICtrl, new TipsViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.LevelRewardUICtrl, new LevelRewardUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.SignInViewUICtrl, new SignInViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.MakeupConfirmUICtrl, new MakeupConfirmUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.SaveingPotUICtrl, new SaveingPotUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.ResurgenceUICtrl, new ResurgenceUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.FirstRewardUICtrl, new FirstRewardUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.ThreeDaysGiftUICtrl, new ThreeDaysGiftUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RewardMulNewUICtrl, new RewardMulNewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.PassViewUICtrl, new PassViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.PassunlockUICtrl, new PassunlockUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.BroadcastUICtrl, new BroadcastUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RecordViewUICtrl, new RecordViewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.AdcomingUICtrl, new AdcomingUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.FAQUICtrl, new FAQUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.AddViewoffUICtrl, new AddViewoffUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RankUICtrl, new RankUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RankRewardUICtrl, new RankRewardUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.RankRuleUICtrl, new RankRuleUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.PackrewardUICtrl, new PackrewardUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.GoldRewardUICtrl, new GoldRewardUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.AddviewnewUICtrl, new AddviewnewUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.NewTaskUICtrl, new NewTaskUICtrl());
            moduleManager.AddUICtrl(UICtrlConst.GetTaskRewardUICtrl, new GetTaskRewardUICtrl());
        }

        public static void AutoRegisterCtrl()
        {
            ModuleManager moduleManager = ModuleManager.Instance;
            moduleManager.AddCtrl(CtrlConst.RewardAniCtrl, new RewardAniCtrl());
            moduleManager.AddCtrl(CtrlConst.GameLoginCtrl, new GameLoginCtrl());
            moduleManager.AddCtrl(CtrlConst.JoastCtrl, new JoastCtrl());
            moduleManager.AddCtrl(CtrlConst.LoadingCtrl, new LoadingCtrl());
            moduleManager.AddCtrl(CtrlConst.MenuCtrl, new MenuCtrl());
            moduleManager.AddCtrl(CtrlConst.NetLoadingCtrl, new NetLoadingCtrl());
            moduleManager.AddCtrl(CtrlConst.OpenBgCtrl, new OpenBgCtrl());
            moduleManager.AddCtrl(CtrlConst.PrivacyCtrl, new PrivacyCtrl());
            moduleManager.AddCtrl(CtrlConst.RewardCtrl, new RewardCtrl());
            moduleManager.AddCtrl(CtrlConst.PreferencesDataReadyCtrl, new PreferencesDataReadyCtrl());
            moduleManager.AddCtrl(CtrlConst.RainPlayCtrl, new RainPlayCtrl());
            moduleManager.AddCtrl(CtrlConst.ChoosePropCtrl, new ChoosePropCtrl());
            moduleManager.AddCtrl(CtrlConst.BuyPropCtrl, new BuyPropCtrl());
            moduleManager.AddCtrl(CtrlConst.GameResultCtrl, new GameResultCtrl());
            moduleManager.AddCtrl(CtrlConst.AddViewCtrl, new AddViewCtrl());
            moduleManager.AddCtrl(CtrlConst.OpenGameCtrl, new OpenGameCtrl());
            moduleManager.AddCtrl(CtrlConst.RewardboxCtrl, new RewardboxCtrl());
            moduleManager.AddCtrl(CtrlConst.PayloadingCtrl, new PayloadingCtrl());
            moduleManager.AddCtrl(CtrlConst.HallCtrl, new HallCtrl());
            moduleManager.AddCtrl(CtrlConst.FXWndCtrl, new FXWndCtrl());
            moduleManager.AddCtrl(CtrlConst.WheelViewCtrl, new WheelViewCtrl());
            moduleManager.AddCtrl(CtrlConst.BuygoldCtrl, new BuygoldCtrl());
            moduleManager.AddCtrl(CtrlConst.GameMenuCtrl, new GameMenuCtrl());
            moduleManager.AddCtrl(CtrlConst.EggViewCtrl, new EggViewCtrl());
            moduleManager.AddCtrl(CtrlConst.PersonViewCtrl, new PersonViewCtrl());
            moduleManager.AddCtrl(CtrlConst.TipsViewCtrl, new TipsViewCtrl());
            moduleManager.AddCtrl(CtrlConst.LevelRewardCtrl, new LevelRewardCtrl());
            moduleManager.AddCtrl(CtrlConst.SignInViewCtrl, new SignInViewCtrl());
            moduleManager.AddCtrl(CtrlConst.MakeupConfirmCtrl, new MakeupConfirmCtrl());
            moduleManager.AddCtrl(CtrlConst.SaveingPotCtrl, new SaveingPotCtrl());
            moduleManager.AddCtrl(CtrlConst.ResurgenceCtrl, new ResurgenceCtrl());
            moduleManager.AddCtrl(CtrlConst.FirstRewardCtrl, new FirstRewardCtrl());
            moduleManager.AddCtrl(CtrlConst.ThreeDaysGiftCtrl, new ThreeDaysGiftCtrl());
            moduleManager.AddCtrl(CtrlConst.RewardMulNewCtrl, new RewardMulNewCtrl());
            moduleManager.AddCtrl(CtrlConst.PassViewCtrl, new PassViewCtrl());
            moduleManager.AddCtrl(CtrlConst.PassunlockCtrl, new PassunlockCtrl());
            moduleManager.AddCtrl(CtrlConst.BroadcastCtrl, new BroadcastCtrl());
            moduleManager.AddCtrl(CtrlConst.RecordViewCtrl, new RecordViewCtrl());
            moduleManager.AddCtrl(CtrlConst.AdcomingCtrl, new AdcomingCtrl());
            moduleManager.AddCtrl(CtrlConst.FAQCtrl, new FAQCtrl());
            moduleManager.AddCtrl(CtrlConst.AddViewoffCtrl, new AddViewoffCtrl());
            moduleManager.AddCtrl(CtrlConst.RankCtrl, new RankCtrl());
            moduleManager.AddCtrl(CtrlConst.RankRewardCtrl, new RankRewardCtrl());
            moduleManager.AddCtrl(CtrlConst.RankRuleCtrl, new RankRuleCtrl());
            moduleManager.AddCtrl(CtrlConst.PackrewardCtrl, new PackrewardCtrl());
            moduleManager.AddCtrl(CtrlConst.GoldRewardCtrl, new GoldRewardCtrl());
            moduleManager.AddCtrl(CtrlConst.AddviewnewCtrl, new AddviewnewCtrl());
            moduleManager.AddCtrl(CtrlConst.NewTaskCtrl, new NewTaskCtrl());
            moduleManager.AddCtrl(CtrlConst.GetTaskRewardCtrl, new GetTaskRewardCtrl());
        }

        public static void AutoRegisterUIType()
        {
            ModuleManager moduleManager = ModuleManager.Instance;
            moduleManager.AddUIType(UIConst.RewardAniUI, typeof(RewardAniUI));
            moduleManager.AddUIType(UIConst.FXWndUI, typeof(FXWndUI));
            moduleManager.AddUIType(UIConst.GameLoginUI, typeof(GameLoginUI));
            moduleManager.AddUIType(UIConst.JoastUI, typeof(JoastUI));
            moduleManager.AddUIType(UIConst.LoadingUI, typeof(LoadingUI));
            // moduleManager.AddUIType(UIConst.MaskUI, typeof(MaskUI));
            moduleManager.AddUIType(UIConst.MenuUI, typeof(MenuUI));
            moduleManager.AddUIType(UIConst.NetLoadingUI, typeof(NetLoadingUI));
            moduleManager.AddUIType(UIConst.OpenBgUI, typeof(OpenBgUI));
            moduleManager.AddUIType(UIConst.PrivacyUI, typeof(PrivacyUI));
            moduleManager.AddUIType(UIConst.RewardUI, typeof(RewardUI));
            moduleManager.AddUIType(UIConst.RainPlayUI, typeof(RainPlayUI));
            moduleManager.AddUIType(UIConst.ChoosePropUI, typeof(ChoosePropUI));
            moduleManager.AddUIType(UIConst.BuyPropUI, typeof(BuyPropUI));
            moduleManager.AddUIType(UIConst.GameResultUI, typeof(GameResultUI));
            moduleManager.AddUIType(UIConst.AddViewUI, typeof(AddViewUI));
            moduleManager.AddUIType(UIConst.OpenGameUI, typeof(OpenGameUI));
            moduleManager.AddUIType(UIConst.RewardboxUI, typeof(RewardboxUI));
            moduleManager.AddUIType(UIConst.PayloadingUI, typeof(PayloadingUI));
            moduleManager.AddUIType(UIConst.HallUI, typeof(HallUI));
            moduleManager.AddUIType(UIConst.WheelViewUI, typeof(WheelViewUI));
            moduleManager.AddUIType(UIConst.BuygoldUI, typeof(BuygoldUI));
            moduleManager.AddUIType(UIConst.GameMenuUI, typeof(GameMenuUI));
            moduleManager.AddUIType(UIConst.EggViewUI, typeof(EggViewUI));
            moduleManager.AddUIType(UIConst.PersonViewUI, typeof(PersonViewUI));
            moduleManager.AddUIType(UIConst.TipsViewUI, typeof(TipsViewUI));
            moduleManager.AddUIType(UIConst.LevelRewardUI, typeof(LevelRewardUI));
            moduleManager.AddUIType(UIConst.SignInViewUI, typeof(SignInViewUI));
            moduleManager.AddUIType(UIConst.MakeupConfirmUI, typeof(MakeupConfirmUI));
            moduleManager.AddUIType(UIConst.SaveingPotUI, typeof(SaveingPotUI));
            moduleManager.AddUIType(UIConst.ResurgenceUI, typeof(ResurgenceUI));
            moduleManager.AddUIType(UIConst.FirstRewardUI, typeof(FirstRewardUI));
            moduleManager.AddUIType(UIConst.ThreeDaysGiftUI, typeof(ThreeDaysGiftUI));
            moduleManager.AddUIType(UIConst.RewardMulNewUI, typeof(RewardMulNewUI));
            moduleManager.AddUIType(UIConst.PassViewUI, typeof(PassViewUI));
            moduleManager.AddUIType(UIConst.PassunlockUI, typeof(PassunlockUI));
            moduleManager.AddUIType(UIConst.BroadcastUI, typeof(BroadcastUI));
            moduleManager.AddUIType(UIConst.RecordViewUI, typeof(RecordViewUI));
            moduleManager.AddUIType(UIConst.AdcomingUI, typeof(AdcomingUI));
            moduleManager.AddUIType(UIConst.FAQUI, typeof(FAQUI));
            moduleManager.AddUIType(UIConst.AddViewoffUI, typeof(AddViewoffUI));
            moduleManager.AddUIType(UIConst.RankUI, typeof(RankUI));
            moduleManager.AddUIType(UIConst.RankRewardUI, typeof(RankRewardUI));
            moduleManager.AddUIType(UIConst.RankRuleUI, typeof(RankRuleUI));
            moduleManager.AddUIType(UIConst.PackrewardUI, typeof(PackrewardUI));
            moduleManager.AddUIType(UIConst.GoldRewardUI, typeof(GoldRewardUI));
            moduleManager.AddUIType(UIConst.AddviewnewUI, typeof(AddviewnewUI));
            moduleManager.AddUIType(UIConst.NewTaskUI, typeof(NewTaskUI));
            moduleManager.AddUIType(UIConst.GetTaskRewardUI, typeof(GetTaskRewardUI));
        }
    }
}